pygerber.renderer.aperture.rectangular module
=============================================

.. automodule:: pygerber.renderer.aperture.rectangular
   :members:
   :undoc-members:
   :show-inheritance:
